==> apeman-app-sign-4.0.4.tgz: package/lib/doing/do_one_sign_pass.js <==
/**
 * @function doOneSignPass
 */
'use strict'

const co = require('co')
const DynamicModel = require('../modeling/dynamic_model')
const errors = require('../errors')
const modelToData = require('apeman-app-rest/lib/modeling/model_to_data')
const successPayload = require('apeman-app-rest/lib/payloads/success_payload')
const failurePayload = require('apeman-app-rest/lib/payloads/failure_payload')
const typeOfModel = require('apeman-app-rest/lib/naming/type_of_model')
const NameConstants = require('../constants/name_constants')

/** @lends doOneSignPass */
function doOneSignPass (config) {
  const ACTION_NAME = 'one'
  let success = successPayload(ACTION_NAME)
  let fail = failurePayload(ACTION_NAME)
  let name = NameConstants.SIGN_PASS_NAME

  let _includedAfterOne = (included) => co(function * () {
    for (let i of [].concat(included || [])) {
      let attributes = i.attributes
      delete attributes.hash
      delete attributes.hashSalt
    }
    return included
  })

  function oneSignPass (UserSign, context) {
    let id = context.id
    return co(function * () {
      let req = context.req
      let signed = req.signed()
      let hit = signed && signed.id === id
      if (!hit) {
        return fail(errors.notFoundError(name, id))
      }
      let sign = new DynamicModel(signed.sign)
      let result = success(
        {},
        {
          type: typeOfModel(name),
          id: id,
          relationships: {
            sign: {
              data: modelToData.withoutAttributes(UserSign.$name, sign)
            }
          }
        },
        {},
        [
          modelToData(UserSign.$name, sign, {})
        ]
      )
      result.included = yield _includedAfterOne(result.included)
      return result
    })
  }

  return oneSignPass
}

module.exports = doOneSignPass

==> apeman-app-sign-4.0.7.tgz: package/lib/doing/do_one_sign_pass.js <==
/**
 * @function doOneSignPass
 */
'use strict'

const co = require('co')
const errors = require('../errors')
const apemanmodel = require('apemanmodel')
const successPayload = require('apeman-app-rest/lib/payloads/success_payload')
const failurePayload = require('apeman-app-rest/lib/payloads/failure_payload')
const NameConstants = require('../constants/name_constants')

/** @lends doOneSignPass */
function doOneSignPass (config) {
  const ACTION_NAME = 'one'
  let success = successPayload(ACTION_NAME)
  let fail = failurePayload(ACTION_NAME)
  let name = NameConstants.SIGN_PASS_NAME

  let _includedAfterOne = (included) => co(function * () {
    for (let i of [].concat(included || [])) {
      let attributes = i.attributes
      delete attributes.hash
      delete attributes.hashSalt
    }
    return included
  })

  function oneSignPass (UserSign, context) {
    let id = context.id
    return co(function * () {
      let req = context.req
      let signed = req.signed()
      let hit = signed && signed.id === id
      if (!hit) {
        return fail(errors.notFoundError(name, id))
      }
      let sign = apemanmodel.dynamicModel(signed.sign)
      let result = success(
        {},
        {
          type: apemanmodel.toType(name),
          id: id,
          relationships: {
            sign: {
              data: apemanmodel.toData.withoutAttributes(UserSign, sign)
            }
          }
        },
        {},
        [
          apemanmodel.toData(UserSign, sign, {})
        ]
      )
      result.included = yield _includedAfterOne(result.included)
      return result
    })
  }

  return oneSignPass
}

module.exports = doOneSignPass
